pub struct Message {
pub role: Role,
pub content: MessageContent,
pub name: Option<String>,
pub metadata: Option<Value>,
}Expand description
A message in the conversation
Fields
role: RoleRole of the message sender
content: MessageContentContent of the message
name: Option<String>Optional name for the message sender (useful for multi-agent conversations)
metadata: Option<Value>Optional metadata
Implementations
Sourceimpl Message
impl Message
Sourcepub fn tool_result<S: Into<String>>(tool_use_id: S, content: S) -> Self
pub fn tool_result<S: Into<String>>(tool_use_id: S, content: S) -> Self
Create a tool result message
Sourcepub fn text_or_summary(&self) -> String
pub fn text_or_summary(&self) -> String
Get a text representation of the message content, including Blocks. For Text messages, returns the text directly. For Blocks messages, concatenates text from all blocks into a readable summary so that conversation history is preserved when serializing for API calls.